datastructuretools.CyclicPayloadTree
====================================

.. abjad-lineage:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree

.. autoclass:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.children
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.depth
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.expr
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.get_manifest_payload_of_next_n_nodes_at_level
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.get_next_n_complete_nodes_at_level
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.get_next_n_nodes_at_level
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.get_node_at_position
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.get_position_of_descendant
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.graphviz_format
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.graphviz_graph
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.improper_parentage
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.index
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.index_in_parent
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.is_at_level
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.item_class
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.iterate_at_level
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.iterate_depth_first
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.iterate_forever_depth_first
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.iterate_payload
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.level
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.manifest_payload
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.negative_level
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.payload
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.position
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.proper_parentage
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.remove_node
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.remove_to_root
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.root
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.to_nested_lists
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.width
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__contains__
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__eq__
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__format__
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__getitem__
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__hash__
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__iter__
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__len__
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__ne__
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__repr__

Bases
-----

- :py:class:`datastructuretools.PayloadTree <abjad.tools.datastructuretools.PayloadTree.PayloadTree>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.children
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.depth
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.expr
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.graphviz_format
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.graphviz_graph
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.index_in_parent
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.item_class
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.level
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.manifest_payload
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.negative_level
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.payload
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.position
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.root
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.width
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.get_manifest_payload_of_next_n_nodes_at_level
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.get_next_n_complete_nodes_at_level
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.get_next_n_nodes_at_level
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.get_node_at_position
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.get_position_of_descendant
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.index
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.is_at_level
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.iterate_at_level
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.iterate_depth_first
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.iterate_forever_depth_first
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.iterate_payload
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.remove_node
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.remove_to_root
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.to_nested_lists
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__hash__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__iter__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree.__repr__
   :noindex:
